[totem] Fix reading from ObexFTP
- From: Bastien Nocera <hadess src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [totem] Fix reading from ObexFTP
- Date: Thu, 18 Feb 2010 10:16:54 +0000 (UTC)
commit e7d13ff52e591c030f0e4413e105e6ae79fcccaa
Author: Bastien Nocera <hadess hadess net>
Date: Thu Feb 18 10:13:23 2010 +0000
Fix reading from ObexFTP
Only works with the new osso-gwobex ObexFTP backend, but works
well enough.
https://bugzilla.gnome.org/show_bug.cgi?id=579874
src/backend/bacon-video-widget-gst-0.10.c | 5 +++--
1 files changed, 3 insertions(+), 2 deletions(-)
---
diff --git a/src/backend/bacon-video-widget-gst-0.10.c b/src/backend/bacon-video-widget-gst-0.10.c
index 3e19739..703390e 100644
--- a/src/backend/bacon-video-widget-gst-0.10.c
+++ b/src/backend/bacon-video-widget-gst-0.10.c
@@ -3578,8 +3578,9 @@ bacon_video_widget_open (BaconVideoWidget * bvw,
file = g_file_new_for_commandline_arg (mrl);
/* Only use the URI when FUSE isn't available for a file
- * or we're trying to read from an archive */
- if (g_file_has_uri_scheme (file, "archive") != FALSE)
+ * or we're trying to read from an archive or ObexFTP */
+ if (g_file_has_uri_scheme (file, "archive") != FALSE ||
+ g_file_has_uri_scheme (file, "obex") != FALSE)
path = NULL;
else
path = g_file_get_path (file);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]